"use client";

import React from "react";
import { FaFilm, FaTv, FaHome, FaSearch, FaEllipsisH } from "react-icons/fa";
import { usePathname, useRouter } from "next/navigation";
import { motion } from "framer-motion";

const MobileNavBar: React.FC = () => {
  const pathname = usePathname();
  const router = useRouter();

  const navItems = [
    { id: 2, icon: FaFilm, route: "/movies" },
    { id: 3, icon: FaTv, route: "/tvshows" },
    { id: 1, icon: FaHome, route: "/" },
    { id: 4, icon: FaSearch, route: "/search" },
    { id: 5, icon: FaEllipsisH, route: "/more" },
  ];

  return (
    <nav className="fixed bottom-0 left-0 w-full bg-black bg-opacity-60 backdrop-blur-md border-t border-gray-700 z-50 md:hidden">
      <div className="flex justify-around items-center h-16">
        {navItems.map((item) => {
          const Icon = item.icon;
          const isActive = pathname === item.route;

          return (
            <motion.div
              key={item.id}
              className="flex-1 flex justify-center items-center relative"
              whileHover={{ scale: 1.15 }}
              whileTap={{ scale: 0.95 }}
              onClick={() => router.push(item.route)}
            >
              <motion.div
                className={`flex justify-center items-center p-2 rounded-full transition-all duration-300 ${
                  isActive
                    ? "text-red-500 bg-white bg-opacity-10"
                    : "text-gray-400"
                }`}
                whileHover={{
                  scale: 1.15,
                }}
                whileTap={{
                  scale: 0.95,
                }}
              >
                <Icon className="text-3xl transition-all duration-300 ease-in-out" />
              </motion.div>

              {isActive && (
                <motion.div
                  layoutId="active-underline"
                  className="absolute bottom-0 w-8 h-1 bg-red-600 rounded-full"
                  initial={{ opacity: 0, scaleX: 0 }}
                  animate={{ opacity: 1, scaleX: 1 }}
                  exit={{ opacity: 0, scaleX: 0 }}
                  transition={{ duration: 0.4, ease: "easeInOut" }}
                />
              )}
            </motion.div>
          );
        })}
      </div>
    </nav>
  );
};

export default MobileNavBar;
